==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Misc/MiscDevelopment/EcmaScriptShell/ts/EcmaScriptShell_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>EcmaScriptShell</name>
    <message>
        <location filename="../EcmaScriptShell.js" line="+58"/>
        <source>Show ECMAScript Shell</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+38"/>
        <source>&amp;Script Shell</source>
        <translation>&amp;Ukazna lupina</translation>
    </message>
    <message>
        <location line="+25"/>
        <location filename="../EcmaScriptShell.ui" line="+14"/>
        <source>Script Shell</source>
        <translation>Ukazna lupina</translation>
    </message>
    <message>
        <location filename="../EcmaScriptShellDialog.ui" line="+20"/>
        <source>ECMAScript Shell</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+15"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;You are about to enable the ECMAScript Shell.&lt;/p&gt;&lt;p&gt;Through the ECMAScript Shell you can &lt;span style=&quot; color:#ff0000;&quot;&gt;modify your drawings&lt;/span&gt; but also &lt;span style=&quot; color:#ff0000;&quot;&gt;delete files&lt;/span&gt; or &lt;span style=&quot; color:#ff0000;&quot;&gt;crash the application&lt;/span&gt; which can lead to &lt;span style=&quot; color:#ff0000;&quot;&gt;data loss&lt;/span&gt;.&lt;/p&gt;&lt;p&gt;For inexperienced programmers, it is recommended to limit the use of the ECMAScript shell to the &lt;a href=&quot;http://www.qcad.org/doc/qcad/latest/developer/group__ecma__simple.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;QCAD Simple API&lt;/span&gt;&lt;/a&gt; which is considered to be &apos;safe&apos; to use.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Don&apos;t show this dialog again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Misc/MiscDevelopment/EcmaScriptShell/ts/EcmaScriptShell_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>EcmaScriptShell</name>
    <message>
        <location filename="../EcmaScriptShell.js" line="+58"/>
        <source>Show ECMAScript Shell</source>
        <translation>Prikaži ECMAScript lupino</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>&amp;Script Shell</source>
        <translation>&amp;Ukazna lupina</translation>
    </message>
    <message>
        <location line="+25"/>
        <location filename="../EcmaScriptShell.ui" line="+14"/>
        <source>Script Shell</source>
        <translation>Ukazna lupina</translation>
    </message>
    <message>
        <location filename="../EcmaScriptShellDialog.ui" line="+20"/>
        <source>ECMAScript Shell</source>
        <translation>ECMAScript lupina</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;You are about to enable the ECMAScript Shell.&lt;/p&gt;&lt;p&gt;Through the ECMAScript Shell you can &lt;span style=&quot; color:#ff0000;&quot;&gt;modify your drawings&lt;/span&gt; but also &lt;span style=&quot; color:#ff0000;&quot;&gt;delete files&lt;/span&gt; or &lt;span style=&quot; color:#ff0000;&quot;&gt;crash the application&lt;/span&gt; which can lead to &lt;span style=&quot; color:#ff0000;&quot;&gt;data loss&lt;/span&gt;.&lt;/p&gt;&lt;p&gt;For inexperienced programmers, it is recommended to limit the use of the ECMAScript shell to the &lt;a href=&quot;http://www.qcad.org/doc/qcad/latest/developer/group__ecma__simple.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;QCAD Simple API&lt;/span&gt;&lt;/a&gt; which is considered to be &apos;safe&apos; to use.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ste tik pred teme da aktivirate ECMAScript lupinol.&lt;/p&gt;&lt;p&gt;Skozi ECMAScript lupino lahko &lt;span style=&quot; color:#ff0000;&quot;&gt;spremenite vaše risbe&lt;/span&gt;&lt;br/&gt; kakor tudi &lt;span style=&quot; color:#ff0000;&quot;&gt;izbrišete datoteke&lt;/span&gt; ali &lt;span style=&quot; color:#ff0000;&quot;&gt;sesujete program&lt;/span&gt;,&lt;br/&gt; kar lahko privede do &lt;span style=&quot; color:#ff0000;&quot;&gt;izgube podatkov&lt;/span&gt;.&lt;/p&gt;&lt;p&gt;Za neizkušene programerje, je priporočeno omejit&lt;br/&gt; uporabo ECMAScript lupine na &lt;a href=&quot;http://www.qcad.org/doc/qcad/latest/developer/group__ecma__simple.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;QCAD Simple API&lt;/span&gt;&lt;/a&gt;,&lt;br/&gt; katera je obravnavana kot &quot;varna&quot; za uporabo.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Don&apos;t show this dialog again</source>
        <translation>Ne prikaži več tega okna</translation>
    </message>
</context>
</TS>
